TokenResponse class

Constructors

TokenResponse.fromJson(Map<String, dynamic> json)

Properties

accessToken → String?
OAuth 2.0 Access Token
no setter
expiresAt → DateTime?
no setter
expiresIn → Duration?
Expiration time of the Access Token since the response was generated.
no setter
hashCode → int
The hash code for this object.
no setterinherited
idToken → IdToken
ID Token
no setter
refreshToken → String?
Refresh token
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenType → String?
OAuth 2.0 Token Type value
no setter

Methods

getTyped<T>(String key, {T factory(dynamic v)?}) → T?
Returns the property key as a typed object
inherited
getTypedList<T>(String key, {T factory(dynamic v)?}) → List<T>?
Returns the property key as a typed list
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedString() → String
Returns the base64 representation
inherited
toBytes() → List<int>
Returns the bytes representing the encoded JSON
inherited
toJson() → Map<String, dynamic>
Returns a JSON representation
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String key) → dynamic
Returns the property key as a core dart value
inherited